@@ -1,4 +1,5 @@
 import numpy as np
+import xarray as xr
 
 def epsilon_soil_moisture(ef_24):
     r"""
@@ -78,7 +79,11 @@ def stress_radiation(ra_24):
     0.90322580645161288
     """
     stress = ra_24/(ra_24 + 60.)*(1 + 60./500.)
-    stress = np.clip(stress, 0, 1)
+    
+    if isinstance(stress, xr.DataArray):
+        stress = stress.clip(0, 1)
+    else:
+        stress = np.clip(stress, 0, 1)
 
     return stress
 
@@ -124,7 +129,11 @@ def stress_moisture(se_root, tenacity=1.5):
     1.0
     """
     stress = tenacity*se_root - (np.sin(2*np.pi*se_root))/(2*np.pi)
-    stress = np.clip(stress, 0, 1)
+
+    if isinstance(stress, xr.DataArray):
+        stress = stress.clip(0,1)
+    else:
+        stress = np.clip(stress, 0, 1)
 
     return stress
 
@@ -185,8 +194,12 @@ def stress_temperature(t_air_24, t_opt=25.0, t_min=0.0, t_max=50.0):
     y = (t_opt - t_min) * (t_max - t_opt)**f
 
     stress = x/y
-    stress = np.clip(stress, 0, 1)
 
+    if isinstance(stress, xr.DataArray):
+        stress = stress.clip(0, 1)
+    else:
+        stress = np.clip(stress, 0, 1)
+        
     return stress
 
 
@@ -229,6 +242,11 @@ def stress_vpd(vpd_24, vpd_slope=-0.3):
 
     """
     stress = vpd_slope * np.log(vpd_24/10. + 0.5) + 1
-    stress = np.clip(stress, 0, 1)
+
+    if isinstance(stress, xr.DataArray):
+        stress = stress.clip(0, 1)
+    else:
+        stress = np.clip(stress, 0, 1)
+
 
     return stress
