@@ -1,9 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-Authors: Tim Hessels
-Module: WAPOR/Functions
-"""
-
 from pywapor.general import variables, processing_functions, compositer, pre_defaults, lazifier, network, reproject, levels
 
 __all__ = ['variables', 'processing_functions', 'compositer', 'pre_defaults', 'lazifier', 'network', 'reproject', 'levels']
